#include <HelMod.h>
#include <fstream>
#include <iostream>
#include <vector>

int main(int argc, char* argv[]) {

    // ******************** check argument ********************
    if (argc != 3) {
        std::cerr << "Usage:  <input_flux_lis>  <output_flux_toa>"
                  << std::endl;
        return 1;
    }

    std::string lis_filename = argv[1];
    std::string out_filename = argv[2];
    // ******************** ************** ********************

    // ************** read input LIS into arrays **************
    std::vector<double> v_ekin_lis, v_flux_lis;

    std::ifstream ifs(lis_filename);
    double e, f;
    while (ifs >> e >> f) {
        v_ekin_lis.push_back(e);
        v_flux_lis.push_back(f);
    }
    ifs.close();

    std::valarray<double> ekin_lis(v_ekin_lis.data(), v_ekin_lis.size());
    std::valarray<double> flux_lis(v_flux_lis.data(), v_flux_lis.size());
    // ************** ************************** **************

    // ************* construct a modulator object *************
#if 1
    HelMod::Modulator ams_mod({1, 1}, 20110519, 20131126);
    //                        {Z, A}, start_time, end_time
#else
    // if the path was not built in library, it must be provided manually
    std::string archive_path = "/path/to/helmod_data";
    HelMod::Modulator ams_mod({1, 1, archive_path}, 20110519, 20131126);
#endif
    // ************* **************************** *************

    // ************** calculate solar modulation **************
    std::valarray<double> flux_toa;
#if 0
    // energy grid for modulated spectrum can be specified
    std::valarray<double> ekin_toa = ekin_lis;
    flux_toa = ams_mod.modulate(ekin_lis, flux_lis, flux_toa);
#else
    // without providing the 3rd argument, the modulated
    // flux shares the same energy grid as input LIS
    flux_toa = ams_mod.modulate(ekin_lis, flux_lis);
#endif
    // ************** ************************** **************

    // ************ write modulated flux into file ************
    std::ofstream ofs(out_filename);
    ofs << std::scientific;
    for (size_t i = 0; i < flux_toa.size(); ++i) {
        ofs << ekin_lis[i] << '\t' << flux_toa[i] << std::endl;
    }
    ofs.close();
    // ************ ****************************** ************

    return 0;
}
